@@ -3,7 +3,7 @@
 from PyQt4.QtCore import Qt, QVariant, QModelIndex, QAbstractTableModel, qWarning
 
 class StockMatchTableModel(QAbstractTableModel):
-    HEADER = [u"代號 Ticker", u"名稱 Name"]
+
     COL_TICKER = 0
     COL_NAME = 1
 
@@ -126,6 +126,7 @@ class StockMatchTableModel(QAbstractTableModel):
 
     def __init__(self, parent=None, *args):
         QAbstractTableModel.__init__(self, parent, *args)
+        self.HEADER = [self.tr("Ticker"), self.tr("Name")]
         self.table = []
 
     def data(self, index, role):
